summaryrefslogtreecommitdiffstats
path: root/sync/test/engine/injectable_sync_context_proxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'sync/test/engine/injectable_sync_context_proxy.h')
-rw-r--r--sync/test/engine/injectable_sync_context_proxy.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sync/test/engine/injectable_sync_context_proxy.h b/sync/test/engine/injectable_sync_context_proxy.h
index ca8bc02..4f19d9c 100644
--- a/sync/test/engine/injectable_sync_context_proxy.h
+++ b/sync/test/engine/injectable_sync_context_proxy.h
@@ -11,11 +11,11 @@
namespace syncer_v2 {
-class ModelTypeSyncProxyImpl;
+class ModelTypeProcessorImpl;
class CommitQueue;
// A SyncContextProxy implementation that, when a connection request is made,
// initalizes a connection to a previously injected ModelTypeSyncProxyImpl.
class InjectableSyncContextProxy : public SyncContextProxy {
public:
explicit InjectableSyncContextProxy(CommitQueue* queue);
@@ -25,7 +25,7 @@ class InjectableSyncContextProxy : public SyncContextProxy {
syncer::ModelType type,
const DataTypeState& data_type_state,
const UpdateResponseDataList& pending_updates,
- const base::WeakPtr<ModelTypeSyncProxyImpl>& type_sync_proxy) override;
+ const base::WeakPtr<ModelTypeProcessorImpl>& type_sync_proxy) override;
void Disconnect(syncer::ModelType type) override;
scoped_ptr<SyncContextProxy> Clone() const override;
@@ -11,11 +11,11 @@
class CommitQueue;
// A SyncContextProxy implementation that, when a connection request is made,
-// initalizes a connection to a previously injected ModelTypeSyncProxyImpl.
+// initalizes a connection to a previously injected ModelTypeProcessorImpl.
class InjectableSyncContextProxy : public SyncContextProxy {
public: